@@ -534,7 +534,26 @@ def Disc(center=(0.,0.,0.), inner=0.25, outer=0.5, normal=(0,0,1), r_res=1,
     src.SetRadialResolution(r_res)
     src.SetCircumferentialResolution(c_res)
     src.Update()
-    return pyvista.wrap(src.GetOutput())
+
+    default_normal = np.array([0, 0, 1])
+    normal = np.array(normal)
+    center = np.array(center)
+
+    axis = np.cross(default_normal, normal)
+    angle = np.rad2deg(np.arccos(
+        np.clip(np.dot(normal, default_normal), -1, 1)))
+
+    transform = vtk.vtkTransform()
+    transform.Translate(-center)
+    transform.RotateWXYZ(angle, axis)
+    transform.Translate(center)
+
+    transform_filter = vtk.vtkTransformFilter()
+    transform_filter.SetInputConnection(src.GetOutputPort())
+    transform_filter.SetTransform(transform)
+    transform_filter.Update()
+
+    return pyvista.wrap(transform_filter.GetOutput())
 
 
 def Text3D(string, depth=0.5):
@@ -554,24 +573,6 @@ def Text3D(string, depth=0.5):
     return pyvista.wrap(tri_filter.GetOutput())
 
 
-def SuperToroid(*args, **kwargs):
-    """Create a super toroid.
-
-    DEPRECATED: Please use `pyvista.ParametricSuperToroid` instead.
-
-    """
-    raise NotImplementedError('use `pyvista.ParametricSuperToroid` instead')
-
-
-def Ellipsoid(*args, **kwargs):
-    """Create an ellipsoid.
-
-    DEPRECATED: Please use :func:`pyvista.ParametricEllipsoid` instead.
-
-    """
-    raise NotImplementedError('use `pyvista.ParametricEllipsoid` instead')
-
-
 def Wavelet(extent=(-10,10,-10,10,-10,10), center=(0,0,0), maximum=255,
             x_freq=60, y_freq=30, z_freq=40, x_mag=10, y_mag=18, z_mag=5,
             std=0.5, subsample_rate=1):
